Changes
=======

v0.3.0: (UPCOMING)
*******************
 - Make "Add" mode default when clicking on "Create Particle Layer"
 - Read/write support for filaments in CBOX format
 - Read/write support for filament in helicon format
 - Support to save all filaments to directory
 - Add a simplified call for the boxmanager 'napari_boxmanager'
 - Many bug fixes

v0.2.10:
*******************
 - Fix bug when reading .tloc files with long paths (Thanks Tom Dendooven)
 - Fix bug with contrast issues when low pass filter images
 - Add smooth fall-off when low pass filtering images
